GalleryImageSaveOptions class

Annotations

Constructors

GalleryImageSaveOptions({required String name, required String fileExtension, required String? albumName})
const

Properties

albumName → String?
final
fileExtension → String
final
hashCode → int
The hash code for this object.
no setteroverride
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override