ImageSaveResult class

Annotations

Constructors

ImageSaveResult({required String? filePath, required String? blobUrl})
const
ImageSaveResult.io({required String? filePath})
factory
ImageSaveResult.web({required String blobUrl})
factory

Properties

blobUrl → String?
final
filePath → String?
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override