QuillNativeBridge class

An internal plugin for flutter_quill package to access platform-specific APIs.

Use QuillNativeBridge.isSupported to check whether a feature is supported.

Constructors

QuillNativeBridge()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyHtmlToClipboard(String html) → Future<void>
Copies an HTML to the system clipboard to be pasted on other apps.
copyImageToClipboard(Uint8List imageBytes) → Future<void>
Copies an image to the system clipboard to be pasted on other apps.
getClipboardFiles() → Future<List<String>>
Returns the file paths from the system clipboard.
getClipboardGif() → Future<Uint8List?>
Returns the copied GIF image from the system clipboard.
getClipboardHtml() → Future<String?>
Returns a HTML from the system clipboard. The HTML can be platform-dependent.
getClipboardImage() → Future<Uint8List?>
Returns the copied image from the system clipboard.
isAppleSafari() → bool
Returns whether the current browser is Safari on the web.
isIOSSimulator() → Future<bool>
Checks if the app runs on iOS Simulator.
isSupported(QuillNativeBridgeFeature feature) → Future<bool>
Checks if the specified feature is supported in the current implementation.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openGalleryApp() → Future<void>
Opens the system gallery app. Supports Android, iOS, Windows and macOS only.
saveImage(Uint8List imageBytes, {required ImageSaveOptions options}) → Future<ImageSaveResult>
Saves an image to the user's device based on the platform:
saveImageToGallery(Uint8List imageBytes, {required GalleryImageSaveOptions options}) → Future<void>
Saves an image to the gallery app on supported platforms. Supports Android, iOS, and macOS.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited