UtilityWidgets class abstract final

Provides utiulity widgets.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

maybeTooltip({required Widget child, String? message}) → Widget
Conditionally wraps the child with Tooltip widget if message is not null and not empty.
maybeWidget({required WidgetWrapper wrapper, required Widget child, bool enabled = false}) → Widget
Conditionally wraps the child with wrapper widget if enabled is true.