DeltaIterator class

Specialized iterator for Deltas.

Constructors

DeltaIterator(Delta delta)

Properties

delta → Delta
final
hashCode → int
The hash code for this object.
no setterinherited
hasNext → bool
no setter
isNextDelete → bool
no setter
isNextInsert → bool
no setter
isNextRetain → bool
no setter
nextOperationKey → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

next([int length = maxLength]) → Operation
Consumes and returns next operation.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
peekLength() → int
Returns length of next operation without consuming it.
skip(int length) → Operation?
Skips length characters in source delta.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

maxLength → const int